@@ -3,6 +3,8 @@ package My::Build::MacOSX_wx_config;
 use strict;
 use base qw(My::Build::Any_wx_config);
 
+use Config;
+
 sub awx_wx_config_data {
     my $self = shift;
     return $self->{awx_data} if $self->{awx_data};
@@ -37,4 +39,22 @@ sub awx_configure {
 sub awx_build_toolkit { 'mac' }
 sub awx_dlext { 'dylib' }
 
+sub build_wxwidgets {
+    my( $self ) = @_;
+
+    # can't build wxWidgets 2.8.x with 64 bit Perl
+    if(    $Config{ptrsize} == 8
+        && $self->notes( 'build_data' )->{data}{version} =~ /^2.8/ ) {
+        print <<EOT;
+======================================================================
+Can't build wxWidgets 2.8.x to work with a 64-bit Perl, you will need
+to recompile your Perl as a 32-bit binary.
+======================================================================
+EOT
+        exit 1;
+    }
+
+    $self->SUPER::build_wxwidgets;
+}
+
 1;
